@@ -7,18 +7,26 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Tokenu vypršala platnosť alebo app nie je povolená! Obnovte prosím stránku!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Vnútorná chyba servera! Skontrolujte prosím súbor data/nextcloud.log pre podrobnejšie informácie!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Požiadavka zlyhala, Nextcloud je momentálne v režime údržby!",
+    "News feeds" : "Spravodajský kanál",
     "Unread articles" : "Neprečítané články",
     "News" : "Správy",
+    "News folders" : "Priečinky pre spravodajstvo",
+    "Shared with me" : "Zdieľané so mnou",
     "An RSS/Atom feed reader" : "RSS/Atom čítačka",
     "Use system cron for updates" : "Použiť systémový plánovač cron pre aktualizácie",
+    "Disable this if you use a custom updater." : "Toto vypnite ak používate vlastný updater.",
     "Purge interval" : "Vynulovať interval",
     "Maximum read count per feed" : "Maximálny počet noviniek pre kanál",
     "Maximum redirects" : "Maximum presmerovaní",
     "Feed fetcher timeout" : "Vypršal čas pre sťahovanie článkov",
     "Explore Service URL" : "Prehľadať URL služby",
+    "For more information check the wiki." : "Viac informácií nájdete v našej wiki.",
+    "Update interval" : "Interval aktualizácie",
+    "For more information check the documentation." : "Pre ďaľšie informácie pozrite do dokumentácie.",
     "Saved" : "Uložené",
     "Download" : "Sťahovanie",
     "Close" : "Zavrieť",
+    "Subscribe to" : "Odobrať z",
     "No articles available" : "Žiadne články nie sú dostupné",
     "No unread articles available" : "Žiadne neprečítané články nie sú dostupné",
     "Open website" : "Otvoriť webstránku",
@@ -26,9 +34,16 @@ OC.L10N.register(
     "Unstar article" : "Odobrať hviezdičku",
     "Keep article unread" : "Ponechať ako neprečítaný",
     "Remove keep article unread" : "Odstrániť označenie ako neprečítaný",
+    "Share" : "Zdieľať",
+    "Share with users" : "Zdieľať s užívateľmi",
     "Username" : "Používateľské meno",
+    "No users found" : "Žiadny užívatelia nenájdený",
+    "Error while searching for users" : "Chyba pri vyhľadávaní užívateľov",
+    "Share on social media" : "Zdieľať cez sociálne médiá",
+    "Check out this article" : "Prečítajte si tento článok",
     "by" : "od",
     "from" : "z",
+    "shared by" : "zdieľané s",
     "Play audio" : "Prehrávanie audia",
     "Download audio" : "Stiahnuť audio",
     "Download video" : "Stiahnuť video",
@@ -66,6 +81,7 @@ OC.L10N.register(
     "Credentials" : "Prihlasovanie údaje",
     "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Prihlasovacie údaje pre HTTP Basic Auth musia byť uložené nezašifrované! Každý s prístupom k serveru alebo databáze si ich bude môcť prečítať!",
     "Password" : "Heslo",
+    "Auto discover Feed" : "Automaticky objavovať Informačný kanál",
     "New Folder" : "Nový priečinok",
     "Create" : "Vytvoriť",
     "Explore" : "Preskúmať",
