@@ -18,13 +18,13 @@ use OCA\News\Service\Exceptions\ServiceNotFoundException;
 use OCA\News\Service\FeedServiceV2;
 use OCA\News\Service\FolderServiceV2;
 use OCA\News\Service\ImportService;
+use OCA\News\Service\ItemServiceV2;
 use OCP\AppFramework\Http\JSONResponse;
 use OCP\IRequest;
 use OCP\IConfig;
 use OCP\AppFramework\Http;
 
-use OCA\News\Service\ItemService;
-use OCA\News\Db\FeedType;
+use OCA\News\Db\ListType;
 use OCP\IUserSession;
 
 class FeedController extends Controller
@@ -35,7 +35,9 @@ class FeedController extends Controller
      * @var FeedServiceV2
      */
     private $feedService;
-    //TODO: Remove
+    /**
+     * @var ItemServiceV2
+     */
     private $itemService;
     /**
      * @var FolderServiceV2
@@ -54,7 +56,7 @@ class FeedController extends Controller
         IRequest $request,
         FolderServiceV2 $folderService,
         FeedServiceV2 $feedService,
-        ItemService $itemService,
+        ItemServiceV2 $itemService,
         ImportService $importService,
         IConfig $settings,
         ?IUserSession $userSession
@@ -79,11 +81,11 @@ class FeedController extends Controller
         // item id which will be used for marking feeds read
         $params = [
             'feeds' => $this->feedService->findAllForUser($this->getUserId()),
-            'starred' => $this->itemService->starredCount($this->getUserId())
+            'starred' => count($this->itemService->starred($this->getUserId()))
         ];
 
         try {
-            $id = $this->itemService->getNewestItemId($this->getUserId());
+            $id = $this->itemService->newest($this->getUserId())->getId();
 
             // An exception occurs if there is a newest item. If there is none,
             // simply ignore it and do not add the newestItemId
@@ -120,10 +122,10 @@ class FeedController extends Controller
 
             $feedType = intval($feedType);
             switch ($feedType) {
-                case FeedType::FOLDER:
+                case ListType::FOLDER:
                     $this->folderService->find($this->getUserId(), $feedId);
                     break;
-                case FeedType::FEED:
+                case ListType::FEED:
                     $this->feedService->find($this->getUserId(), $feedId);
                     break;
                 default:
@@ -131,7 +133,7 @@ class FeedController extends Controller
             }
         } catch (ServiceNotFoundException $ex) {
             $feedId = 0;
-            $feedType = FeedType::SUBSCRIPTIONS;
+            $feedType = ListType::ALL_ITEMS;
         }
 
         return [
@@ -159,7 +161,8 @@ class FeedController extends Controller
         ?int $parentFolderId,
         ?string $title = null,
         ?string $user = null,
-        ?string $password = null
+        ?string $password = null,
+        bool $fullDiscover = true
     ) {
         if ($parentFolderId === 0) {
             $parentFolderId = null;
@@ -176,14 +179,15 @@ class FeedController extends Controller
                 false,
                 $title,
                 $user,
-                $password
+                $password,
+                $fullDiscover
             );
             $params = ['feeds' => [$feed]];
 
             $this->feedService->fetch($feed);
 
             try {
-                $id = $this->itemService->getNewestItemId($this->getUserId());
+                $id = $this->itemService->newest($this->getUserId())->getId();
                 // An exception occurs if there is a newest item. If there is none,
                 // simply ignore it and do not add the newestItemId
                 $params['newestItemId'] = $id;
@@ -261,10 +265,10 @@ class FeedController extends Controller
         $feed = $this->importService->importArticles($this->getUserId(), $json);
 
         $params = [
-            'starred' => $this->itemService->starredCount($this->getUserId())
+            'starred' => count($this->itemService->starred($this->getUserId()))
         ];
 
-        if ($feed) {
+        if (!is_null($feed)) {
             $params['feeds'] = [$feed];
         }
 
@@ -281,7 +285,7 @@ class FeedController extends Controller
      */
     public function read(int $feedId, int $highestItemId): array
     {
-        $this->itemService->readFeed($feedId, $highestItemId, $this->getUserId());
+        $this->feedService->read($this->getUserId(), $feedId, $highestItemId);
 
         return [
             'feeds' => [
@@ -333,7 +337,7 @@ class FeedController extends Controller
         ?bool $fullTextEnabled = null,
         ?int $updateMode = null,
         ?int $ordering = null,
-        ?int $folderId = null,
+        ?int $folderId = -1,
         ?string $title = null
     ) {
         try {
@@ -342,8 +346,10 @@ class FeedController extends Controller
             return $this->error($ex, Http::STATUS_NOT_FOUND);
         }
 
-        $fId = $folderId === 0 ? null : $folderId;
-        $feed->setFolderId($fId);
+        if ($folderId !== -1) {
+            $fId = $folderId === 0 ? null : $folderId;
+            $feed->setFolderId($fId);
+        }
         if ($pinned !== null) {
             $feed->setPinned($pinned);
         }
